==> makeen-expressionengine-0.0.51.tgz: package/src/compiler/parts/aggregateFunctionCallPart.ts <==
﻿import { expressionPart } from './expressionPart';
import { aggregateFunction } from '../../functions/aggregateFunction';
import expressionData from '../../expressionData';
import { groupDataContext } from '../../functions/groupDataContext';
import List from 'typescript-dotnet-commonjs/System/Collections/List';
import { format } from "typescript-dotnet-commonjs/System/Text/Utility";
import { outputVariables } from '../../utils/outputVariables';
export class aggregateFunctionCallPart extends expressionPart {
    _function!: aggregateFunction;
    public get Function(): aggregateFunction {
        return this._function;
    }
    public set Function(value: aggregateFunction) {
        this._function = value;
    }
    parameters!: List<expressionPart>;

    public get simpleName(): string {
        return this.Function.FunctionName;
    }

    public resolve(expressionData: expressionData, resolved: outputVariables, running: groupDataContext, evaluateAllContexts: boolean = true, setValue: Object | undefined = undefined): Object | undefined {
        resolved.resolved = true;
        if ((this.parameters.count > 0)) {
            let current: Object = this.parameters.get(0).resolve(expressionData, resolved, running) as Object;
            let runningValue: Object | undefined = running != null && running.Data != null && running.Data.containsKey(this) ? running.Data.getValue(this) : undefined;

            let result: Object = this.Function.invoke(expressionData, current, runningValue as Object, this.parameters, resolved);
            if (running != null && running.Data != null) {
                let d = { key: this, value: result }
                if (!running.Data.containsKey(this)) {
                    running.Data.add(d);
                }
            }

            return result;
        }
        else {
            return undefined;
        }

    }

    public toString(): string {
        return format("{0}({1})", this.Function.FunctionName, this.parameters.toArray().join(", "));
    }
}

==> makeen-expressionengine-0.0.63.tgz: package/src/compiler/parts/aggregateFunctionCallPart.ts <==
﻿import { expressionPart } from './expressionPart';
import { aggregateFunction } from '../../functions/aggregateFunction';
import expressionData from '../../expressionData';
import { groupDataContext } from '../../functions/groupDataContext';
import { format } from "typescript-dotnet-commonjs/System/Text/Utility";
import { outputVariables } from '../../utils/outputVariables';
export class aggregateFunctionCallPart extends expressionPart {
    _function!: aggregateFunction;
     get Function(): aggregateFunction {
        return this._function;
    }
     set Function(value: aggregateFunction) {
        this._function = value;
    }
    parameters!: expressionPart[];

     get simpleName(): string {
        return this.Function.FunctionName;
    }

     resolve(expressionData: expressionData, resolved: outputVariables, running: groupDataContext, evaluateAllContexts: boolean = true, setValue: Object | undefined = undefined): Object | undefined {
        resolved.resolved = true;
        if ((this.parameters.length > 0)) {
            let current: Object = this.parameters[0].resolve(expressionData, resolved, running) as Object;
            let runningValue: Object | undefined = running != null && running.Data != null && running.Data.containsKey(this) ? running.Data.getValue(this) : undefined;

            let result: Object = this.Function.invoke(expressionData, current, runningValue as Object, this.parameters, resolved);
            if (running != null && running.Data != null) {
                let d = { key: this, value: result }
                if (!running.Data.containsKey(this)) {
                    running.Data.add(d);
                }
            }

            return result;
        }
        else {
            return undefined;
        }

    }

     toString(): string {
        return format("{0}({1})", this.Function.FunctionName, this.parameters.join(", "));
    }
}
